@@ -31,7 +31,6 @@ static int contains_word(char *str, char *str2);
 static int is_zip(hd_t *hd);
 static void int_floppy(hd_data_t *hd_data);
 static void int_fix_usb_scsi(hd_data_t *hd_data);
-static void int_fix_usb_network(hd_data_t *hd_data);
 static void int_mouse(hd_data_t *hd_data);
 static void new_id(hd_data_t *hd_data, hd_t *hd);
 static void int_modem(hd_data_t *hd_data);
@@ -48,7 +47,6 @@ static void int_legacy_geo(hd_data_t *hd_data);
 static void int_find_parent(hd_data_t *hd_data);
 static void int_add_driver_modules(hd_data_t *hd_data);
 static void int_update_driver_data(hd_data_t *hd_data, hd_t *hd);
-static int is_usb_storage(hd_t *hd);
 
 
 void hd_scan_int(hd_data_t *hd_data)
@@ -103,9 +101,6 @@ void hd_scan_int(hd_data_t *hd_data)
   PROGRESS(8, 0, "usbscsi");
   int_fix_usb_scsi(hd_data);
 
-  PROGRESS(17, 0, "usbnetwork");
-  int_fix_usb_network(hd_data);
-
   PROGRESS(9, 0, "hotplug");
   int_hotplug(hd_data);
 
@@ -616,26 +611,23 @@ void int_floppy(hd_data_t *hd_data)
 
 
 /*
- * Remove usb entries that are handled by a usb storage driver.
- *
- * USB disks are handled in block.c and usb.c - this can lead to incorrect
- * duplicate entries.
+ * Remove usb entries that are handled by usb-storage.
  */
 void int_fix_usb_scsi(hd_data_t *hd_data)
 {
   hd_t *hd_scsi, *hd_usb;
 
-  for(hd_usb = hd_data->hd; hd_usb; hd_usb = hd_usb->next) {
+  for(hd_usb = hd_data->hd; hd_usb; hd_usb= hd_usb->next) {
     if(
       hd_usb->bus.id == bus_usb &&
       hd_usb->sysfs_id &&
-      is_usb_storage(hd_usb)
+      search_str_list(hd_usb->drivers, "usb-storage")
     ) {
       for(hd_scsi = hd_data->hd; hd_scsi; hd_scsi = hd_scsi->next) {
         if(
           hd_scsi->bus.id == bus_scsi &&
           hd_scsi->sysfs_device_link &&
-          is_usb_storage(hd_scsi)
+          search_str_list(hd_scsi->drivers, "usb-storage")
         ) {
           if(!strncmp(hd_scsi->sysfs_device_link, hd_usb->sysfs_id, strlen(hd_usb->sysfs_id))) {
             hd_set_hw_class(hd_scsi, hw_usb);
@@ -678,82 +670,6 @@ void int_fix_usb_scsi(hd_data_t *hd_data)
 }
 
 
-/*
- * Remove usb network entries that are duplicates of network cards handled
- * in other places (like pci.c - e.g. platform devices).
- *
- */
-void int_fix_usb_network(hd_data_t *hd_data)
-{
-  hd_t *hd_net, *hd_usb;
-
-  for(hd_net = hd_data->hd; hd_net; hd_net = hd_net->next) {
-    if(
-      !hd_net->tag.remove &&
-      hd_net->base_class.id == bc_network &&
-      hd_net->sysfs_id
-    ) {
-      for(hd_usb = hd_data->hd; hd_usb; hd_usb = hd_usb->next) {
-        if(
-          hd_usb != hd_net &&
-          !hd_usb->tag.remove &&
-          hd_usb->bus.id == bus_usb &&
-          hd_usb->sysfs_id &&
-          !strcmp(hd_usb->sysfs_id, hd_net->sysfs_id)
-        ) {
-          hd_set_hw_class(hd_net, hw_usb);
-
-          free_mem(hd_net->unique_id);
-          hd_net->unique_id = hd_usb->unique_id;
-          hd_usb->unique_id = NULL;
-
-          add_res_entry(&hd_net->res, hd_usb->res);
-          hd_usb->res = NULL;
-
-          if(hd_usb->modalias) {
-            free_mem(hd_net->modalias);
-            hd_net->modalias = hd_usb->modalias;
-            hd_usb->modalias = NULL;
-          }
-
-          if(hd_usb->vendor.id) {
-            hd_net->vendor.id = hd_usb->vendor.id;
-            free_mem(hd_net->vendor.name);
-            hd_net->vendor.name = hd_usb->vendor.name;
-            hd_usb->vendor.name = NULL;
-          }
-
-          if(hd_usb->device.id) {
-            hd_net->device.id = hd_usb->device.id;
-            free_mem(hd_net->device.name);
-            hd_net->device.name = hd_usb->device.name;
-            hd_usb->device.name = NULL;
-          }
-
-          if(hd_usb->serial) {
-            free_mem(hd_net->serial);
-            hd_net->serial = hd_usb->serial;
-            hd_usb->serial = NULL;
-          }
-
-          if(hd_usb->driver_info) {
-            free_driver_info(hd_net->driver_info);
-            hd_net->driver_info = hd_usb->driver_info;
-            hd_usb->driver_info = NULL;
-          }
-
-          new_id(hd_data, hd_net);
-
-          hd_usb->tag.remove = 1;
-        }
-      }
-    }
-  }
-
-  remove_tagged_hd_entries(hd_data);
-}
-
-
 /*
  * Improve mouse info.
  */
@@ -1427,25 +1343,5 @@ void hd_add_driver_data(hd_data_t *hd_data, hd_t *hd)
   int_update_driver_data(hd_data, hd);
 }
 
-
-/*
- * Return 1 if an usb storage driver is used, otherwise 0.
- *
- * Storage drivers can be usb-storage or uas.
- */
-int is_usb_storage(hd_t *hd)
-{
-  int is_storage = 0;
-
-  if(
-    search_str_list(hd->drivers, "usb-storage") ||
-    search_str_list(hd->drivers, "uas")
-  ) {
-    is_storage = 1;
-  }
-
-  return is_storage;
-}
-
 /** @} */
 
